/*
 * This file is generated by objective.metadata
 *
 * Last update: Sun Jun 26 10:58:31 2022
 */

static void __attribute__((__used__)) use_protocols(void)
{
    PyObject* p __attribute__((__unused__));
#if PyObjC_BUILD_RELEASE >= 1300
    p = PyObjC_IdToPython(@protocol(MTLFXSpatialScaler));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(MTLFXTemporalScaler));
    Py_XDECREF(p);
#endif /* PyObjC_BUILD_RELEASE >= 1300 */
}
